ex_dash v0.1.5 ExDash.Docset
Responsible for building the structure, SQLite DB, and Info.plist of a Dash Docset.
Summary
Functions
build/2 converts a list of project nodes and a config into a Dash Docset,
and writes that docset to your /doc dir
Functions
build(project_nodes, config)
build(list, ExDoc.Config.t) :: {config :: ExDoc.Config.t, docset_path :: String.t}
build/2 converts a list of project nodes and a config into a Dash Docset,
and writes that docset to your /doc dir.
- takes a list of project_nodes and a config
- initializes the directory structure and SQLite DB
- iterates over the project nodes while writes metadata to the DB
- writes content to the Info.plist