ex_dash v0.1.5 Mix.Tasks.Docs.Dash

Run ExDoc with a Dash Docs compatible formatter and output.

Summary

Functions

Builds a Dash Docset for the current Mix project

Types

args()
args() :: [String.t]

Functions

run(args \\ [])
run(args) :: String.t

Builds a Dash Docset for the current Mix project.

Options

  • --open: opens the built docset in Dash following the build. Defaults to true unless the docset exists in the /doc dir before the run.
  • --name NAME: names the docset something other than the app name. Defaults to the project name, or (if an umbrella app) the cwd of the mix task
  • --abbr ABBREVIATION: the default abbreviation to search for your docs with. Default: first two characters of the project name. (i.e. ex for ex_dash).