ex_dash v0.1.5 Mix.Tasks.Docs.Dash
Run ExDoc with a Dash Docs compatible formatter and output.
Summary
Functions
Builds a Dash Docset for the current Mix project
Types
Functions
Builds a Dash Docset for the current Mix project.
Options
--open: opens the built docset in Dash following the build. Defaults to true unless the docset exists in the/docdir before the run.--name NAME: names the docset something other than the app name. Defaults to the project name, or (if an umbrella app) thecwdof the mix task--abbr ABBREVIATION: the default abbreviation to search for your docs with. Default: first two characters of the project name. (i.e.exforex_dash).